==> webkitgtk-2.2.1.tar.xz: webkitgtk-2.2.1/Source/JavaScriptCore/jit/JITToDFGDeferredCompilationCallback.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef JITToDFGDeferredCompilationCallback_h
#define JITToDFGDeferredCompilationCallback_h

#include <wtf/Platform.h>

#if ENABLE(DFG_JIT)

#include "DeferredCompilationCallback.h"
#include <wtf/PassRefPtr.h>

namespace JSC {

class ScriptExecutable;

class JITToDFGDeferredCompilationCallback : public DeferredCompilationCallback {
protected:
    JITToDFGDeferredCompilationCallback();

public:
    virtual ~JITToDFGDeferredCompilationCallback();

    static PassRefPtr<JITToDFGDeferredCompilationCallback> create();
    
    virtual void compilationDidBecomeReadyAsynchronously(CodeBlock*);
    virtual void compilationDidComplete(CodeBlock*, CompilationResult);
};

} // namespace JSC

#endif // ENABLE(DFG_JIT)

#endif // JITToDFGDeferredCompilationCallback_h

==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/JavaScriptCore/jit/JITToDFGDeferredCompilationCallback.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef JITToDFGDeferredCompilationCallback_h
#define JITToDFGDeferredCompilationCallback_h

#include <wtf/Platform.h>

#if ENABLE(DFG_JIT)

#include "DeferredCompilationCallback.h"
#include <wtf/PassRefPtr.h>

namespace JSC {

class ScriptExecutable;

class JITToDFGDeferredCompilationCallback : public DeferredCompilationCallback {
protected:
    JITToDFGDeferredCompilationCallback();

public:
    virtual ~JITToDFGDeferredCompilationCallback();

    static PassRefPtr<JITToDFGDeferredCompilationCallback> create();
    
    virtual void compilationDidBecomeReadyAsynchronously(CodeBlock*) OVERRIDE;
    virtual void compilationDidComplete(CodeBlock*, CompilationResult) OVERRIDE;
};

} // namespace JSC

#endif // ENABLE(DFG_JIT)

#endif // JITToDFGDeferredCompilationCallback_h
